@@ -12,6 +12,8 @@
 # stop_ec2api
 
 
+env | sort
+
 # Save trace setting
 XTRACE=$(set +o | grep xtrace)
 set -o xtrace
@@ -26,6 +28,7 @@ EC2API_CONF_DIR=${EC2API_CONF_DIR:-/etc/ec2api}
 EC2API_CONF_FILE=${EC2API_CONF_DIR}/ec2api.conf
 EC2API_DEBUG=${EC2API_DEBUG:-True}
 EC2API_STATE_PATH=${EC2API_STATE_PATH:=$DATA_DIR/ec2api}
+EC2API_AUTH_CACHE_DIR=${EC2API_AUTH_CACHE_DIR:-/var/cache/ec2api}
 
 EC2API_SERVICE_PORT=${EC2API_SERVICE_PORT:-8788}
 EC2API_S3_SERVICE_PORT=${EC2API_S3_SERVICE_PORT:-3334}
@@ -55,35 +58,32 @@ function recreate_endpoint {
     local port=$3
     local protocol=$4
 
-    if [[ "$KEYSTONE_CATALOG_BACKEND" = 'sql' ]]; then
-
-        # Remove nova's service/endpoint
-        local endpoint_ids=$(openstack --os-identity-api-version 3 endpoint list \
-            --service "$endpoint" --region "$REGION_NAME" -c ID -f value)
-        if [[ -n "$endpoint_ids" ]]; then
-            for endpoint_id in $endpoint_ids ; do
-                openstack --os-identity-api-version 3 endpoint delete $endpoint_id
-            done
-        fi
-        local service_id=$(openstack --os-identity-api-version 3 service list \
-            -c "ID" -c "Name" \
-            | grep " $endpoint " | get_field 1)
-        if [[ -n "$service_id" ]]; then
-            openstack --os-identity-api-version 3 service delete $service_id
-        fi
-
-        local service_id=$(openstack service create \
-            $endpoint \
-            --name "$endpoint" \
-            --description="$description" \
-            -f value -c id)
-        openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
-            $service_id public "$protocol://$SERVICE_HOST:$port/"
-        openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
-            $service_id admin "$protocol://$SERVICE_HOST:$port/"
-        openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
-            $service_id internal "$protocol://$SERVICE_HOST:$port/"
+    # Remove nova's service/endpoint
+    local endpoint_ids=$(openstack --os-identity-api-version 3 endpoint list \
+        --service "$endpoint" --region "$REGION_NAME" -c ID -f value)
+    if [[ -n "$endpoint_ids" ]]; then
+        for endpoint_id in $endpoint_ids ; do
+            openstack --os-identity-api-version 3 endpoint delete $endpoint_id
+        done
     fi
+    local service_id=$(openstack --os-identity-api-version 3 service list \
+        -c "ID" -c "Name" \
+        | grep " $endpoint " | get_field 1)
+    if [[ -n "$service_id" ]]; then
+        openstack --os-identity-api-version 3 service delete $service_id
+    fi
+
+    local service_id=$(openstack service create \
+        $endpoint \
+        --name "$endpoint" \
+        --description="$description" \
+        -f value -c id)
+    openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
+        $service_id public "$protocol://$SERVICE_HOST:$port/"
+    openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
+        $service_id admin "$protocol://$SERVICE_HOST:$port/"
+    openstack --os-identity-api-version 3 endpoint create --region "$REGION_NAME" \
+        $service_id internal "$protocol://$SERVICE_HOST:$port/"
 }
 
 
@@ -179,12 +179,10 @@ function configure_ec2api {
     # ec2api Api Configuration
     #-------------------------
 
-    iniset $EC2API_CONF_FILE DEFAULT admin_tenant_name $SERVICE_TENANT_NAME
-    iniset $EC2API_CONF_FILE DEFAULT admin_user $EC2API_ADMIN_USER
-    iniset $EC2API_CONF_FILE DEFAULT admin_password $SERVICE_PASSWORD
+    configure_auth_token_middleware $EC2API_CONF_FILE $EC2API_ADMIN_USER $EC2API_AUTH_CACHE_DIR
 
     iniset $EC2API_CONF_FILE DEFAULT ec2api_workers "$API_WORKERS"
-    iniset $EC2API_CONF_FILE DEFAULT keystone_url "$KEYSTONE_SERVICE_PROTOCOL://$KEYSTONE_SERVICE_HOST:$KEYSTONE_SERVICE_PORT/v2.0"
+    iniset $EC2API_CONF_FILE DEFAULT keystone_ec2_tokens_url "$KEYSTONE_SERVICE_URI_V3/ec2tokens"
     iniset $EC2API_CONF_FILE DEFAULT region_list "$REGION_NAME"
 
     iniset $EC2API_CONF_FILE DEFAULT ec2api_listen_port "$EC2API_SERVICE_PORT"
@@ -246,18 +244,17 @@ function install_ec2api() {
 
 # start_ec2api() - Start running processes, including screen
 function start_ec2api() {
-    screen_it ec2-api "cd $EC2API_DIR && $EC2API_BIN_DIR/ec2-api --config-file $EC2API_CONF_DIR/ec2api.conf"
-    screen_it ec2-api-metadata "cd $EC2API_DIR && $EC2API_BIN_DIR/ec2-api-metadata --config-file $EC2API_CONF_DIR/ec2api.conf"
-    screen_it ec2-api-s3 "cd $EC2API_DIR && $EC2API_BIN_DIR/ec2-api-s3 --config-file $EC2API_CONF_DIR/ec2api.conf"
+    run_process ec2-api "$EC2API_BIN_DIR/ec2-api --config-file $EC2API_CONF_DIR/ec2api.conf"
+    run_process ec2-api-metadata "$EC2API_BIN_DIR/ec2-api-metadata --config-file $EC2API_CONF_DIR/ec2api.conf"
+    run_process ec2-api-s3 "$EC2API_BIN_DIR/ec2-api-s3 --config-file $EC2API_CONF_DIR/ec2api.conf"
 }
 
 
 # stop_ec2api() - Stop running processes
 function stop_ec2api() {
-    # Kill the ec2api screen windows
-    screen -S $SCREEN_NAME -p ec2-api -X kill
-    screen -S $SCREEN_NAME -p ec2-api-metadata -X kill
-    screen -S $SCREEN_NAME -p ec2-api-s3 -X kill
+    stop_process ec2-api
+    stop_process ec2-api-metadata
+    stop_process ec2-api-s3
 }
 
 function cleanup_ec2api() {
@@ -287,6 +284,7 @@ elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
     echo_summary "Initializing ec2-api"
     init_ec2api
     start_ec2api
+elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
     configure_functional_tests
 fi
 
