@@ -242,7 +242,10 @@ def skip_without_vpc(*args, **kwargs):
 
 
 def check_network_feature_enabled(ext_name):
-    ext_list = CONF['network-feature-enabled']['api_extensions']
+    if hasattr(CONF, 'network_feature_enabled'):
+        ext_list = CONF.network_feature_enabled.api_extensions
+    else:
+        ext_list = ['all']
     if 'all' not in ext_list and ext_name not in ext_list:
         msg = ("Skipped network test as %s is not available" % ext_name)
         raise testtools.TestCase.skipException(msg)
